
##########################
Citing MusicBox
##########################

.. toctree::
   :maxdepth: 1

MusicBox is a group scientific and software effort. The software can be cited like this:

.. code-block:: console

  @software{dawson_2025_15427735,
    author       = {Dawson, Matthew and
                    Shores, Kyle and
                    Conley, Andrew and
                    De la Garza, Evan and
                    Drury, Walker and
                    Garza, Alexander and
                    Fattig, Brendan and
                    Drews, Carl and
                    Thind, Montek and
                    Kiran, Aditya},
    title        = {MusicBox},
    month        = may,
    year         = 2025,
    publisher    = {Zenodo},
    version      = {v2.8.0},
    doi          = {10.5281/zenodo.15427735},
    url          = {https://doi.org/10.5281/zenodo.15427735}
